# Midnight Journal

A simple TUI Journal for [Midnight](https://midnight.hackclub.com)

## Features

- A simple TUI based interface
- Save you Journals
- Markdown rendering
- Auto scroll


## Setup(macOS)

Make a virtual environment
```
python3 -m venv .venv
```

Activate virtual environment

Windows:
```
.venv\Scripts\activate
```

Linux/macOS:
```
source .venv/bin/activate
```

### Install dependencies

```
uv sync
```

### Run Project

```
uv run app.py
```

## Development

### Install `textual-dev`

```
uv add textual-dev
```

Made with ❤️ by DragonSenseiGuy for [Midnight](https://midnight.hackclub.com)
